// vim: set tabstop=4 shiftwidth=4 noexpandtab
/*
Copyright (c) 2003 Jos van den Oever

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
#ifndef METAEDIT_H
#define METAEDIT_H

// TQt
#include <tqvbox.h>

// KDE
#include <tdefilemetainfo.h>
class TQTextEdit;

namespace Gwenview {

class Document;

class MetaEdit : public TQVBox {
Q_OBJECT
  
public:
	MetaEdit(TQWidget *parent, Document*, const char *name="");
	~MetaEdit();
protected:
	bool eventFilter(TQObject *, TQEvent *);
private slots:
	void updateContent();
	void updateDoc();
	void setModified(bool);

private:
	bool mEmpty;
	Document* mDocument;
	TQTextEdit* mCommentEdit;

	void setComment(const TQString&);
	void setMessage(const TQString&);
	void setEmptyText();
};


} // namespace
#endif

